@@ -61,6 +61,34 @@ OB_DUPLIGROUP = 1 << 8
 PTCACHE_DISK_CACHE = 64
 PTCACHE_EXTERNAL = 512
 
+# DNA_ID_types.h
+IDP_STRING = 0
+IDP_INT = 1
+IDP_FLOAT = 2
+IDP_ARRAY = 5
+IDP_GROUP = 6
+IDP_ID = 7
+IDP_DOUBLE = 8
+IDP_IDPARRAY = 9
+IDP_NUMTYPES = 10
+
+# DNA_node_types.h
+SOCK_CUSTOM = -1  # socket has no integer type
+SOCK_FLOAT = 0
+SOCK_VECTOR = 1
+SOCK_RGBA = 2
+SOCK_SHADER = 3
+SOCK_BOOLEAN = 4
+SOCK_MESH = 5  # deprecated
+SOCK_INT = 6
+SOCK_STRING = 7
+SOCK_OBJECT = 8
+SOCK_IMAGE = 9
+SOCK_GEOMETRY = 10
+SOCK_COLLECTION = 11
+SOCK_TEXTURE = 12
+SOCK_MATERIAL = 13
+
 # BKE_pointcache.h
 PTCACHE_FILE_PTCACHE = 0
 PTCACHE_FILE_OPENVDB = 1
